==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/SETCONSISTEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SETCONSISTEQUIPMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SETCONSISTEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETCONSISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SETCONSISTEQUIPMENTID_Type", propOrder = {
    "setconsistid",
    "equipmentid"
})
public class SETCONSISTEQUIPMENTID_Type {

    @XmlElement(name = "SETCONSISTID", required = true)
    protected SETCONSISTID_Type setconsistid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Obtient la valeur de la propriété setconsistid.
     * 
     * @return
     *     possible object is
     *     {@link SETCONSISTID_Type }
     *     
     */
    public SETCONSISTID_Type getSETCONSISTID() {
        return setconsistid;
    }

    /**
     * Définit la valeur de la propriété setconsistid.
     * 
     * @param value
     *     allowed object is
     *     {@link SETCONSISTID_Type }
     *     
     */
    public void setSETCONSISTID(SETCONSISTID_Type value) {
        this.setconsistid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/SETCONSISTEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SETCONSISTEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SETCONSISTEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETCONSISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SETCONSISTEQUIPMENTID_Type", propOrder = {
    "setconsistid",
    "equipmentid"
})
public class SETCONSISTEQUIPMENTID_Type {

    @XmlElement(name = "SETCONSISTID", required = true)
    protected SETCONSISTID_Type setconsistid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Gets the value of the setconsistid property.
     * 
     * @return
     *     possible object is
     *     {@link SETCONSISTID_Type }
     *     
     */
    public SETCONSISTID_Type getSETCONSISTID() {
        return setconsistid;
    }

    /**
     * Sets the value of the setconsistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SETCONSISTID_Type }
     *     
     */
    public void setSETCONSISTID(SETCONSISTID_Type value) {
        this.setconsistid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}
